==> axiom-1.2.21-src.zip: axiom-1.2.21/axiom-api/src/test/java/org/apache/axiom/blob/suite/WritableBlobTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.blob.suite;

import org.apache.axiom.blob.WritableBlob;
import org.apache.axiom.blob.WritableBlobFactory;
import org.apache.axiom.testutils.suite.MatrixTestCase;

public abstract class WritableBlobTestCase extends MatrixTestCase {
    private final WritableBlobFactory factory;
    private final State initialState;

    public WritableBlobTestCase(WritableBlobFactory factory, State initialState) {
        this.factory = factory;
        this.initialState = initialState;
    }

    @Override
    protected final void runTest() throws Throwable {
        WritableBlob blob = factory.createBlob();
        try {
            CleanupCallback cleanupCallback = initialState.transition(blob);
            try {
                runTest(blob);
            } finally {
                if (cleanupCallback != null) {
                    cleanupCallback.cleanup();
                }
            }
        } finally {
            blob.release();
        }
    }
    
    protected abstract void runTest(WritableBlob blob) throws Throwable;
}

==> axiom-1.4.0-src.zip: axiom-1.4.0/axiom-api/src/test/java/org/apache/axiom/blob/suite/WritableBlobTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.blob.suite;

import org.apache.axiom.blob.WritableBlob;
import org.apache.axiom.blob.WritableBlobFactory;
import org.apache.axiom.testutils.suite.MatrixTestCase;

public abstract class WritableBlobTestCase extends MatrixTestCase {
    private final WritableBlobFactory<?> factory;
    private final State initialState;

    public WritableBlobTestCase(WritableBlobFactory<?> factory, State initialState) {
        this.factory = factory;
        this.initialState = initialState;
    }

    @Override
    protected final void runTest() throws Throwable {
        WritableBlob blob = factory.createBlob();
        try {
            CleanupCallback cleanupCallback = initialState.transition(blob);
            try {
                runTest(blob);
            } finally {
                if (cleanupCallback != null) {
                    cleanupCallback.cleanup();
                }
            }
        } finally {
            blob.release();
        }
    }
    
    protected abstract void runTest(WritableBlob blob) throws Throwable;
}
